//
// by Grigoriy Khlytin on 25.10.2022
//

#include <iostream>
#include <algorithm>
#include <vector>

using namespace std;

typedef long long ll;

// int128:

bool myLess(__int128 x, __int128 y) {
    return (x <= y);
}

__int128 myMin(__int128 x, __int128 y) {
    if (x < y) {
        return x;
    } else {
        return y;
    }
}

__int128 myMul(__int128 x, __int128 y) {
    __int128 ans = 1LL;
    ans = ans * x;
    ans = ans * y;
    return ans;
}

// structs:

struct Point {
    ll x, y;
};

struct Vector {
    Point p1, p2;
};

struct Segment {
    Point p1, p2;
};

// methods:

ll sqr(ll x) {
    return x * x;
}

// <= 10^8
ll sqrDistPointToPoint(Point p1, Point p2) {
    return sqr(p1.x - p2.x) + sqr(p1.y - p2.y);
}

// <= 10^4
ll getX(Vector v) {
    return v.p2.x - v.p1.x;
}

// <= 10^4
ll getY(Vector v) {
    return v.p2.y - v.p1.y;
}

// <= 10^8
ll sqrLength(Segment v) {
    return sqrDistPointToPoint(v.p1, v.p2);
}

// <= 10^8
ll scalarProd(Vector v1, Vector v2) {
    return getX(v1) * getX(v2) + getY(v1) * getY(v2);
}

// <= 10^8
ll pseudoProd(Vector v1, Vector v2) {
    return getX(v1) * getY(v2) - getY(v1) * getX(v2);
}

bool checkPointOnSegment(Point p, Segment seg) {
    Vector v1{seg.p1, seg.p2};
    Vector v2{seg.p1, p};
    Vector v3{p, seg.p1};
    Vector v4{p, seg.p2};
    return (pseudoProd(v1, v2) == 0LL && scalarProd(v3, v4) <= 0LL);
}

bool checkPointsOnDifferentSides(Segment seg, Point p1, Point p2) {
    Vector v1{seg.p1, seg.p2};
    Vector v2{seg.p1, p1};
    Vector v3{seg.p1, p2};
    return (pseudoProd(v1, v2) * pseudoProd(v1, v3) < 0LL);
}

bool checkSegmentsIntersect(Segment seg1, Segment seg2) {
    if (checkPointsOnDifferentSides(seg1, seg2.p1, seg2.p2) &&
        checkPointsOnDifferentSides(seg2, seg1.p1, seg1.p2)) {
        return true;
    }
    if (checkPointOnSegment(seg1.p1, seg2) ||
        checkPointOnSegment(seg1.p2, seg2) ||
        checkPointOnSegment(seg2.p1, seg1) ||
        checkPointOnSegment(seg2.p2, seg1)) {
        return true;
    }
    return false;
}

// <= 10^16
ll sqrDistPointToSegmentMulSqrSegLength(Point p, Segment seg) {
    Vector v1{seg.p1, seg.p2};
    Vector v2{seg.p1, p};
    Vector v3{seg.p2, seg.p1};
    Vector v4{seg.p2, p};
    if (scalarProd(v1, v2) >= 0LL && scalarProd(v3, v4) >= 0LL) {
        // the perpendicular hits the segment
        Vector w1{seg.p1, seg.p2};
        Vector w2{seg.p1, p};
        return sqr(pseudoProd(w1, w2));
    }
    return sqrLength(seg) * min(sqrDistPointToPoint(p, seg.p1), sqrDistPointToPoint(p, seg.p2));
}

// warning:
// <= 10^24
__int128 sqrDistSegmentToSegmentMulSegSegLengths(Segment first, Segment second) {
    if (checkSegmentsIntersect(first, second)) {
        return 0LL;
    }
    auto dist1 = myMul(sqrDistPointToSegmentMulSqrSegLength(first.p1, second), sqrLength(first));
    auto dist2 = myMul(sqrDistPointToSegmentMulSqrSegLength(first.p2, second), sqrLength(first));
    auto dist3 = myMul(sqrDistPointToSegmentMulSqrSegLength(second.p1, first), sqrLength(second));
    auto dist4 = myMul(sqrDistPointToSegmentMulSqrSegLength(second.p2, first), sqrLength(second));
    return myMin(myMin(dist1, dist2), myMin(dist3, dist4));
}

// warning:
// <= 10^24
bool mainCheck(Segment A, Segment B, Segment C) {
    auto tmp = myMul(myMul(sqrLength(A), sqrLength(B)), sqrLength(C));
    return (myLess(sqrDistSegmentToSegmentMulSegSegLengths(A, B), tmp) ||
            myLess(sqrDistSegmentToSegmentMulSegSegLengths(A, C), tmp) ||
            myLess(sqrDistSegmentToSegmentMulSegSegLengths(B, C), tmp));
}

int main() {
    ll m;
    cin >> m;

    vector<Segment> segments;

    for (ll i = 0LL; i < m; i++) {
        ll x1, y1, x2, y2;
        cin >> x1 >> y1 >> x2 >> y2;

        auto A1 = Point{x1, y1};
        auto A2 = Point{x2, y2};

        segments.push_back(Segment{A1, A2});
    }

    ll cnt = 0LL;

    for (ll i = 0LL; i < segments.size(); i++) {
        for (ll j = i + 1LL; j < segments.size(); j++) {
            for (ll k = j + 1LL; k < segments.size(); k++) {
                if (mainCheck(segments[i], segments[j], segments[k])) cnt++;
            }
        }
    }

    cout << cnt;

    return 0;
}
